==> calligra_2.8.90.orig.tar.xz: calligra-2.8.90/krita/plugins/paintops/libpaintop/kis_brush_size_option.cpp <==
/*
 *  Copyright (c) 2009,2010 Lukáš Tvrdý <lukast.dev@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#include "kis_brush_size_option.h"
#include <klocale.h>

#include <QWidget>
#include <QRadioButton>

#include "ui_wdgBrushSizeOptions.h"

class KisBrushSizeOptionsWidget: public QWidget, public Ui::WdgBrushSizeOptions
{
public:
    KisBrushSizeOptionsWidget(QWidget *parent = 0)
        : QWidget(parent) {
        setupUi(this);
    }

};


KisBrushSizeOption::KisBrushSizeOption()
    : KisPaintOpOption(i18n("Brush tip"), KisPaintOpOption::generalCategory(), false)
{
    m_checkable = false;
    m_options = new KisBrushSizeOptionsWidget();


    // init slider values
    m_options->diameter->setRange(1.0, 1000, 0);
    m_options->diameter->setValue(20);
    m_options->diameter->setExponentRatio(3.0);
    m_options->diameter->setSuffix(" px");

    m_options->aspectBox->setRange(0.01, 2.0, 2);
    m_options->aspectBox->setValue(1.0);
    m_options->aspectBox->setExponentRatio(1.0);


    m_options->scale->setRange(0.01, 10.0, 2);
    m_options->scale->setValue(1.0);

    m_options->spacing->setRange(0.01, 5.0, 2);
    m_options->spacing->setValue(0.3);


    m_options->rotationBox->setRange(0.0, 360.0, 0);
    m_options->rotationBox->setValue(0.0);
    m_options->rotationBox->setSuffix(QChar(Qt::Key_degree));


    m_options->densityBox->setRange(0.0, 100.0, 0);
    m_options->densityBox->setValue(100);
    m_options->densityBox->setSuffix("%");


    m_options->jitterMove->setRange(0.0, 5.0, 2);
    m_options->jitterMove->setValue(0.0);

    connect(m_options->diameter, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->scale, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->aspectBox, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->spacing, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->rotationBox, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->densityBox, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->jitterMove, SIGNAL(valueChanged(qreal)), SIGNAL(sigSettingChanged()));
    connect(m_options->jitterMoveBox, SIGNAL(toggled(bool)), SIGNAL(sigSettingChanged()));

    connect(m_options->jitterMoveBox, SIGNAL(toggled(bool)), m_options->jitterMove, SLOT(setEnabled(bool)));
    setConfigurationPage(m_options);
}

KisBrushSizeOption::~KisBrushSizeOption()
{
    delete m_options;
}


int KisBrushSizeOption::diameter() const
{
    return qRound(m_options->diameter->value());
}


void KisBrushSizeOption::setDiameter(int diameter)
{
    m_options->diameter->setValue(diameter);
}

qreal KisBrushSizeOption::brushAspect() const
{
    return m_options->aspectBox->value();
}


void KisBrushSizeOption::writeOptionSetting(KisPropertiesConfiguration* setting) const
{
    setting->setProperty(BRUSH_DIAMETER, m_options->diameter->value());
    setting->setProperty(BRUSH_ASPECT, m_options->aspectBox->value());
    setting->setProperty(BRUSH_ROTATION, m_options->rotationBox->value());
    setting->setProperty(BRUSH_SCALE, m_options->scale->value());
    setting->setProperty(BRUSH_SPACING, m_options->spacing->value());
    setting->setProperty(BRUSH_DENSITY, m_options->densityBox->value());
    setting->setProperty(BRUSH_JITTER_MOVEMENT, m_options->jitterMove->value());
    setting->setProperty(BRUSH_JITTER_MOVEMENT_ENABLED, m_options->jitterMoveBox->isChecked());
}

void KisBrushSizeOption::readOptionSetting(const KisPropertiesConfiguration* setting)
{
    m_options->diameter->setValue(setting->getDouble(BRUSH_DIAMETER));
    m_options->aspectBox->setValue(setting->getDouble(BRUSH_ASPECT));
    m_options->rotationBox->setValue(setting->getDouble(BRUSH_ROTATION));
    m_options->scale->setValue(setting->getDouble(BRUSH_SCALE));
    m_options->spacing->setValue(setting->getDouble(BRUSH_SPACING));
    m_options->densityBox->setValue(setting->getDouble(BRUSH_DENSITY));
    m_options->jitterMove->setValue(setting->getDouble(BRUSH_JITTER_MOVEMENT));
    m_options->jitterMoveBox->setChecked(setting->getBool(BRUSH_JITTER_MOVEMENT_ENABLED));

}

void KisBrushSizeOption::setSpacing(qreal spacing)
{
    m_options->spacing->setValue(spacing);
}

qreal KisBrushSizeOption::spacing() const
{
    return m_options->spacing->value();
}

==> calligra-2.9.4.tar.xz: calligra-2.9.4/krita/plugins/paintops/libpaintop/kis_brush_size_option.cpp <==
/*
 *  Copyright (c) 2009,2010 Lukáš Tvrdý <lukast.dev@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#include "kis_brush_size_option.h"
#include <klocale.h>

#include <QWidget>
#include <QRadioButton>

#include "ui_wdgBrushSizeOptions.h"

class KisBrushSizeOptionsWidget: public QWidget, public Ui::WdgBrushSizeOptions
{
public:
    KisBrushSizeOptionsWidget(QWidget *parent = 0)
        : QWidget(parent) {
        setupUi(this);
    }

};


KisBrushSizeOption::KisBrushSizeOption()
    : KisPaintOpOption(i18n("Brush tip"), KisPaintOpOption::generalCategory(), false)
{
    m_checkable = false;
    m_options = new KisBrushSizeOptionsWidget();


    // init slider values
    m_options->diameter->setRange(1.0, 1000, 0);
    m_options->diameter->setValue(20);
    m_options->diameter->setExponentRatio(3.0);
    m_options->diameter->setSuffix(" px");

    m_options->aspectBox->setRange(0.01, 2.0, 2);
    m_options->aspectBox->setValue(1.0);
    m_options->aspectBox->setExponentRatio(1.0);


    m_options->scale->setRange(0.01, 10.0, 2);
    m_options->scale->setValue(1.0);

    m_options->spacing->setRange(0.01, 5.0, 2);
    m_options->spacing->setValue(0.3);


    m_options->rotationBox->setRange(0.0, 360.0, 0);
    m_options->rotationBox->setValue(0.0);
    m_options->rotationBox->setSuffix(QChar(Qt::Key_degree));


    m_options->densityBox->setRange(0.0, 100.0, 0);
    m_options->densityBox->setValue(100);
    m_options->densityBox->setSuffix("%");


    m_options->jitterMove->setRange(0.0, 5.0, 2);
    m_options->jitterMove->setValue(0.0);

    connect(m_options->diameter, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->scale, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->aspectBox, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->spacing, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->rotationBox, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->densityBox, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->jitterMove, SIGNAL(valueChanged(qreal)), SLOT(emitSettingChanged()));
    connect(m_options->jitterMoveBox, SIGNAL(toggled(bool)), SLOT(emitSettingChanged()));

    connect(m_options->jitterMoveBox, SIGNAL(toggled(bool)), m_options->jitterMove, SLOT(setEnabled(bool)));
    setConfigurationPage(m_options);
}

KisBrushSizeOption::~KisBrushSizeOption()
{
    delete m_options;
}


int KisBrushSizeOption::diameter() const
{
    return qRound(m_options->diameter->value());
}


void KisBrushSizeOption::setDiameter(int diameter)
{
    m_options->diameter->setValue(diameter);
}

qreal KisBrushSizeOption::brushAspect() const
{
    return m_options->aspectBox->value();
}


void KisBrushSizeOption::writeOptionSetting(KisPropertiesConfiguration* setting) const
{
    setting->setProperty(BRUSH_DIAMETER, m_options->diameter->value());
    setting->setProperty(BRUSH_ASPECT, m_options->aspectBox->value());
    setting->setProperty(BRUSH_ROTATION, m_options->rotationBox->value());
    setting->setProperty(BRUSH_SCALE, m_options->scale->value());
    setting->setProperty(BRUSH_SPACING, m_options->spacing->value());
    setting->setProperty(BRUSH_DENSITY, m_options->densityBox->value());
    setting->setProperty(BRUSH_JITTER_MOVEMENT, m_options->jitterMove->value());
    setting->setProperty(BRUSH_JITTER_MOVEMENT_ENABLED, m_options->jitterMoveBox->isChecked());
}

void KisBrushSizeOption::readOptionSetting(const KisPropertiesConfiguration* setting)
{
    m_options->diameter->setValue(setting->getDouble(BRUSH_DIAMETER));
    m_options->aspectBox->setValue(setting->getDouble(BRUSH_ASPECT));
    m_options->rotationBox->setValue(setting->getDouble(BRUSH_ROTATION));
    m_options->scale->setValue(setting->getDouble(BRUSH_SCALE));
    m_options->spacing->setValue(setting->getDouble(BRUSH_SPACING));
    m_options->densityBox->setValue(setting->getDouble(BRUSH_DENSITY));
    m_options->jitterMove->setValue(setting->getDouble(BRUSH_JITTER_MOVEMENT));
    m_options->jitterMoveBox->setChecked(setting->getBool(BRUSH_JITTER_MOVEMENT_ENABLED));

}

void KisBrushSizeOption::setSpacing(qreal spacing)
{
    m_options->spacing->setValue(spacing);
}

qreal KisBrushSizeOption::spacing() const
{
    return m_options->spacing->value();
}
